eprllib.Agents.HerarchicalAgentSpec — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.Agents.HerarchicalAgentSpec

## Herarchical Agent Spec

This module implement the base for an agent specification to safe configuration of the object.

Classes

`HerarchicalActionSpec`([action_space]) | HerarchicalActionSpec is the base class for an action specification to safe configuration of the object.
`HerarchicalAgentSpec`([observation, action, ...]) | AgentSpec is the base class for an agent specification to safe configuration of the object.